import React, { Component } from 'react';
import { getControl } from 'zorod/components/Zform/controls';
import { ZsearchListHOC } from 'zorod';
import api from '../Api';
import { Card, Form, Input, Button, message, Icon, Checkbox, Select, Cascader, Table, Popconfirm, Divider } from 'antd';
import DataSourceSetPop from '../popComponents/DataSourceSetPop'

const FormItem=Form.Item;
const TextArea=Input.TextArea;

const formItemLayout = {
    labelCol: { span: 8 },
    wrapperCol: { span: 16 },
  };
  const formTailLayout = {
    labelCol: { span: 4 },
    wrapperCol: { span: 12, offset: 4 },
  };
  const formButtom={
    wrapperCol: { span: 12, offset: 6 }
  }
const residences=["baijing","hunian","guangxi"];

class EcDataSourceList extends Component {
	constructor(props) {
			super(props)
			this.state = {
				dataSource: [],
				selectedRowKeys: [], 
				pagination: {},
				loading: false,
				popShow: true,
				popMode: '',
				popData: {},
				setMode: '',
				searchValues:  {"DATABASE_TYPE": "0"}
			}
	}

	// 页面加载函数
	componentDidMount() {
		api.system.getListDataSource(1, 10, this.state.searchValues).then(res => {
			const pagination = { ...this.state.pagination }
			pagination.current = 1
			pagination.total = res.data.total
			this.setState({
				dataSource: res.data.list,
				pagination
			})
		})
	}

	//表单提交
	handelsubmit=()=>{
			let userInfo=this.props.form.getFieldsValue
			this.props.form.validateFields((err,values)=>{
						if(!err){
							console.log(values)
							message.success(`添加成功!!!`)
						}
			})
	}
	//取消
	handelConcel=()=>{
		this.setState({
			popShow: false
		})
	}
	// 关闭弹窗
	closePop = () => {
		this.setState({
			popShow: true
		})
	}
	// 打开新增弹窗
	sourceAdd = () => {
		this.setState({
			popShow: false,
			popMode: '新增采集数据源',
			popData: {},
			setMode: 'add'
		})
	}
	// 打开更新弹窗
	sourceSet = (key) => {
		api.system.getSingleDataSource(key).then(res => {
			this.setState({
				popShow: false,
				popMode: '采集数据源配置',
				setMode: 'update',
				popData: res.data
			})
		})
	}
	// 打开详情窗口
	sourceDetailSet = (key) => {
		api.system.getSingleDataSource(key).then(res => {
			this.setState({
				popShow: false,
				popMode: '采集数据源详情',
				setMode: '',
				popData: res.data,
				detailMode: false
			})
		})
	}
	// 删除一条数据
	deleteDataSource = (key) => {
		api.system.deleteDataSource(key).then(res => {
			console.log(res)
			api.system.getListDataSource(1, 10, this.state.searchValues).then(res => {
				const pagination = { ...this.state.pagination }
				pagination.current = 1
				pagination.total = res.data.total
				this.setState({
					dataSource: res.data.list,
					pagination
				})
			})
		})
	}
	// 新增一条数据
	addDataSource = (data) => {
		api.system.addDataSource(data).then(res => {
			this.setState({
				popShow: true
			})
			api.system.getListDataSource(1, 10, this.state.searchValues).then(res => {
				const pagination = { ...this.state.pagination }
				pagination.current = 1
				pagination.total = res.data.total
				this.setState({
					dataSource: res.data.list,
					pagination
				})
			})
		})
	}
	// 修改一条数据
	updateDataSource = (data) => {
		api.system.updateDataSource(data).then(res => {
			this.setState({
				popShow: true
			})
			api.system.getListDataSource(1, 10, this.state.searchValues).then(res => {
				const pagination = { ...this.state.pagination }
				pagination.current = 1
				pagination.total = res.data.total
				this.setState({
					dataSource: res.data.list,
					pagination
				})
			})
		})
	}
	// 搜索
	search = () => {
		this.props.form.validateFields((err, values)=>{
			// values = JSON.stringify(values)
			console.log(values)
			this.setState({
				searchValues: values
			})
			api.system.getListDataSource(1, 10, values).then(res => {
				const pagination = { ...this.state.pagination }
				pagination.current = 1
				pagination.total = res.data.total
				this.setState({
					dataSource: res.data.list,
					pagination
				})
			})
		})
	}
	// reload选项
	start = () => {
		this.setState({ loading: true })
		// ajax request after empty completing
		setTimeout(() => {
			this.setState({
				selectedRowKeys: [],
				loading: false,
			})
		}, 1000)
	}
	// 点击选择一行
  onSelectChange = selectedRowKeys => {
    console.log('selectedRowKeys changed: ', selectedRowKeys)
    this.setState({ selectedRowKeys })
  }
	// 点击翻页
	handleTableChange = pagination => {
		const pager = { ...this.state.pagination }
		pager.current = pagination.current
		this.setState({
			pagination: pager,
		})
		api.system.getListDataSource( pagination.current, pagination.pageSize, this.state.searchValues).then(res => {
			const pagination = { ...this.state.pagination }
			this.setState({
				dataSource: res.data.list,
        pagination
			})
		})
	}

	render() { 
		const { getFieldDecorator, getFieldsError, getFieldError, isFieldTouched } = this.props.form
		const columns = [
			{
				title: '名称',
				dataIndex: 'DATATBASE_NAME',
				key: 'DATATBASE_NAME'
			},
			{
				title: '数据源类型',
				dataIndex: 'DATASOURCE_TYPE',
				key: 'DATASOURCE_TYPE',
				render (DATASOURCE_TYPE) {
					let config = {
						'1': '数据库',
						'2': 'API',
						'3': '文件'
					}
					return config[DATASOURCE_TYPE]
				}
			},
			{
				title: 'IP',
				dataIndex: 'DATABASE_IP',
				key: 'DATABASE_IP'
			},
			{
				title: 'url',
				dataIndex: 'DATABASE_URL',
				key: 'DATABASE_URL'
			},
			{
				title: '操作',
				key: 'actions',
				render: (text, record) => (
					<div>
						<Button icon='eye' type='default' size='small' onClick={() => this.sourceDetailSet(record.id)}>详情</Button><Divider type="vertical" />
						<Button icon='edit' type='primary' size='small' onClick={() => this.sourceSet(record.id)}>修改</Button><Divider type="vertical" />
						<Popconfirm placement="topLeft" title='是否确认删除？' onConfirm={() => this.deleteDataSource(record.id)} okText="确认" cancelText="取消">
							<Button icon='delete' type='danger' size='small'>删除</Button>
						</Popconfirm>
					</div>
				)
			}
		]
    const { loading, selectedRowKeys } = this.state
    const rowSelection = {
      selectedRowKeys,
      onChange: this.onSelectChange,
    }
    const hasSelected = selectedRowKeys.length > 0
		return ( 
			<div>
				<div>
					<Card title="数据源配置" extra={<div>
						<Button icon='plus' type='primary' onClick={this.sourceAdd}>新增</Button>
					</div>}>
						<Form>
							<FormItem label="名称" {...formItemLayout}
								style={{ display: 'inline-block', width: 'calc( 22% - 12px)' }}
							>
								{
									getFieldDecorator('DATATBASE_NAME', {
										rules: [
											{
												required: false,
												message: '请输入名称',
											},
										],
									})
									(<Input placeholder="请输入名称" />)
								}
							</FormItem>
							<FormItem label="数据源类型" {...formItemLayout}
								style={{ display: 'inline-block', width: 'calc( 22% - 12px)' }}
							>
								{getFieldDecorator('DATASOURCE_TYPE', {
									initialValue: '0',
									rules: [
										{
											required: false,
											message: '请输入数据源类型',
										},
									],
								})(<Select style={{ width: 100 }}>
									<option value="0">全部</option>
									<option value="1">数据库</option>
									<option value="2">API</option>
									<option value="3">文件</option>
								</Select>)}
							</FormItem>
							<FormItem label="数据库类型" {...formItemLayout}
								style={{ display: 'inline-block', width: 'calc( 22% - 12px)' }}
							>
								{getFieldDecorator('DATATBASE_TYPE', {
									initialValue: '0',
									rules: [
										{
											required: false,
											message: '请输入数据库类型',
										},
									],
								})(<Select style={{ width: 100 }}>
									<option value="0">全部</option>
									<option value="1">MYSQL</option>
									<option value="2">ORACLE</option>
								</Select>)}
							</FormItem>
							<FormItem label="IP" {...formItemLayout}
								style={{ display: 'inline-block', width: 'calc( 22% - 12px)' }}
							>
								{
									getFieldDecorator('DATABASE_IP', {
										rules: [
											{
												required: false,
												message: '请输入IP',
											},
										],
									})
									(<Input placeholder="请输入IP" />)
								}
							</FormItem>
							<FormItem
								style={{ display: 'inline-block', width: 'calc( 10% - 12px)' }}
							>
							<Button icon='search' onClick={this.search} type='primary'>搜索</Button>
							</FormItem>
						</Form>
						<Button type="primary" onClick={this.start} disabled={!hasSelected} loading={loading}>
							重置选择
						</Button>
						<span style={{ marginLeft: 8 }}>
							{hasSelected ? `Selected ${selectedRowKeys.length} items` : ''}
						</span>
						<Table
							rowSelection={rowSelection}
							pagination={this.state.pagination}
							loading={this.state.loading}
							onChange={this.handleTableChange}
							columns={columns}
							dataSource={this.state.dataSource}
						></Table>
					</Card>
					{!this.state.popShow &&
						<DataSourceSetPop
							setMode={this.state.setMode}
							title={this.state.popMode}
							onPopClose={this.closePop}
							onAdd={this.addDataSource}
							onUpdate={this.updateDataSource}
							data={this.state.popData}
						></DataSourceSetPop>
					}
				</div>
			</div>
		)
	}
}
export default Form.create({ name: 'EcDataSourceList' })(EcDataSourceList);
//export default EcTashAdd;